/***************************************************************************************************
 *
 *  Revenge2. Developed by Zeropoint productions. Original version by Scott "Frood" Shingler.
 *
 *  $CLASS        RevengeMessage
 *  $VERSION      1.00 (1-12-2007 15:14)
 *  $AUTHOR       Daan 'Defrost' Scheerens  initial version
 *  $CONTACT      d.scheerens@gmail.com
 *  $DESCRIPTION  Revenge message class. This localized message is send to the player that takes
 *                revenge on another player.
 * edited by rato.skt 30.06.2018 - thiago84.almeida@gmail.com / sound changed !!
 *
 **************************************************************************************************/
class RevengeMessage Extends CriticalEventLowPlus;

#exec AUDIO IMPORT FILE="Resources\RevengeAnnouncer.wav" NAME="RevengeAnnouncer"

var localized string revengeMessage;
var localized string generalRevengeMessage;



/***************************************************************************************************
 *
 *  $DESCRIPTION  Creates the string for this localized message.
 *  $PARAM        switch          Optional message switch.
 *  $PARAM        pri1            Replication info of the first player involved with the message.
 *  $PARAM        pri1            Replication info of the second player involved with the message.
 *  $PARAM        optionalObject  Extra object related to the message.
 *  $RETURN       The message string.
 *
 **************************************************************************************************/
static function string getString(optional int switch, optional PlayerReplicationInfo pri1,
                                 optional PlayerReplicationInfo pri2, optional Object optionalObject) {
	if (pri2 == none) {
		return default.generalRevengeMessage;
	} else {
		return class'RevengeMutator'.static.format(default.revengeMessage, pri2.playerName);
	}
}



/***************************************************************************************************
 *
 *  $DESCRIPTION  Called when the specified client receives this message.
 *  $PARAM        p               The player that has received this message.
 *  $PARAM        switch          Optional message switch.
 *  $PARAM        pri1            Replication info of the first player involved with the message.
 *  $PARAM        pri1            Replication info of the second player involved with the message.
 *  $PARAM        optionalObject  Extra object related to the message.
 *
 **************************************************************************************************/
static function clientReceive(PlayerPawn p, optional int switch, optional playerReplicationInfo pri1, 
                              optional PlayerReplicationInfo pri2, optional Object optionalObject) {
	// Call super.
	super.clientReceive(p, switch, pri1, pri2, optionalObject);
	
	// Play revenge announcer sound at the killers client.
	p.clientPlaySound(Sound'RevengeAnnouncer', , true);
}



/***************************************************************************************************
 *
 *  $DESCRIPTION  Default properties block.
 *
 **************************************************************************************************/
defaultproperties
{
    RevengeMessage="Voce se vingou de >> (~  %1!  ~) "
    generalRevengeMessage="Vengeance!"
    bBeep=False
}
